@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: case-insensitive
 version: 1.2.0.6
-id: case-insensitive-1.2.0.6-c798f9d7ea7ba5a96fa5679d606aad7f
-key: casei_JRhTm2FU9QH5sTVvkKjo8m
+id: case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
+key: casei_4HKCZYPfrJALfK51ySNnwP
 license: BSD3
 copyright: 2011 Bas van Dijk
 maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
@@ -25,14 +25,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.6
 library-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.6
 data-dir: /usr/share/arm-linux-ghc-7.10.3/case-insensitive-1.2.0.6
-hs-libraries: HScase-insensitive-1.2.0.6-JRhTm2FU9QH5sTVvkKjo8m
+hs-libraries: HScase-insensitive-1.2.0.6-4HKCZYPfrJALfK51ySNnwP
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
 haddock-html: /usr/share/doc/haskell-case-insensitive/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
